/**
 * Copyright (c) 2019-present Tomek Wójcik <contact@bthlabs.pl>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

var fs = require('fs');
var path = require('path');

const {expect} = require('chai');

const {spritemaker} = require('../lib/spritemaker');

const {rmtree} = require('./utils');

const ICONS_PATH = path.resolve(__dirname, '..', 'example', 'icons', '*.png');

describe('spritemaker', () => {
  let outputDir = null;
  let defaultOptions = null;

  beforeEach(() => {
    outputDir = fs.mkdtempSync('tmp_spritemaker');
    defaultOptions = {
      files: [ICONS_PATH],
      output: outputDir
    };
  });

  afterEach(() => {
    rmtree(outputDir);
  });

  it('should generate the sprite image', () => {
    const result = spritemaker(defaultOptions);

    const spritePath = path.join(outputDir, result[0]);
    expect(fs.existsSync(spritePath)).to.equal(true);
  });

  it('should generate the SCSS files', () => {
    const result = spritemaker(defaultOptions);

    const scssPath = path.join(outputDir, result[1]);
    expect(fs.existsSync(scssPath)).to.equal(true);
  });
});
